mim — bcselector 0.0.38 documentation

# mim

`bcselector.information_theory.j_criterion_approximations.` `mim`(data, target_variable, candidate_variable_index, **kwargs)

  This estimator computes the Mutual Information Maximisation criterion.

  Parameters

    - data (np.array matrix) – Matrix of data set. Columns are variables, rows are observations.

    - target_variable (int or float) – Target variable. Can not be in data!

    - candidate_variable_index (int) – Index of candidate variable in data matrix.

  Returns

    j_criterion_value – J_criterion approximated by the Mutual Information Maximisation.

  Return type

    float

# mifs

`bcselector.information_theory.j_criterion_approximations.` `mifs`(data, target_variable, prev_variables_index, candidate_variable_index, **kwargs)

  This estimator computes the Mutual Information Feature Selection criterion.

  Parameters

    - data (np.array matrix) – Matrix of data set. Columns are variables, rows are observations.

    - target_variable (int or float) – Target variable. Can not be in data!

    - prev_variables_index (list of ints, set of ints) – Indexes of previously selected variables.

    - candidate_variable_index (int) – Index of candidate variable in data matrix.

    - beta (float) – Impact of redundancy segment in MIFS approximation. Higher the beta is, higher the impact.

  Returns

    j_criterion_value – J_criterion approximated by the Mutual Information Feature Selection.

  Return type

    float

# mrmr

`bcselector.information_theory.j_criterion_approximations.` `mrmr`(data, target_variable, prev_variables_index, candidate_variable_index, **kwargs)

  This estimator computes the Max-Relevance Min-Redundancy criterion.

  Parameters

    - data (np.array matrix) – Matrix of data set. Columns are variables, rows are observations.

    - target_variable (int or float) – Target variable. Can not be in data!

    - prev_variables_index (list of ints) – Indexes of previously selected variables.

    - candidate_variable_index (int) – Index of candidate variable in data matrix.

  Returns

    j_criterion_value – J_criterion approximated by the Max-Relevance Min-Redundancy.

  Return type

    float

# jmi

`bcselector.information_theory.j_criterion_approximations.` `jmi`(data, target_variable, prev_variables_index, candidate_variable_index, **kwargs)

  This estimator computes the Joint Mutual Information criterion.

  Parameters

    - data (np.array matrix) – Matrix of data set. Columns are variables, rows are observations.

    - target_variable (int or float) – Target variable. Can not be in data!

    - prev_variables_index (list of ints) – Indexes of previously selected variables.

    - candidate_variable_index (int) – Index of candidate variable in data matrix.

  Returns

    j_criterion_value – J_criterion approximated by the Joint Mutual Information.

  Return type

    float

# cife

`bcselector.information_theory.j_criterion_approximations.` `cife`(data, target_variable, prev_variables_index, candidate_variable_index, **kwargs)

  This estimator computes the Conditional Infomax Feature Extraction criterion.

  Parameters

    - data (np.array matrix) – Matrix of data set. Columns are variables, rows are observations.

    - target_variable (int or float) – Target variable. Can not be in data!

    - prev_variables_index (list of ints) – Indexes of previously selected variables.

    - candidate_variable_index (int) – Index of candidate variable in data matrix.

    - beta (float) – Impact of redundancy segment in MIFS approximation. Higher the beta is, higher the impact.

  Returns

    j_criterion_value – J_criterion approximated by the Conditional Infomax Feature Extraction.

  Return type

    float